
// This file is automatically generated. Do not edit it directly.
import { createClient, SupabaseClient } from '@supabase/supabase-js';
import type { Database } from './types';
import { ENV } from '@/config/environment';

// Import the supabase client like this:
// import { supabase } from "@/integrations/supabase/client";

// Lazy-initialized Supabase client to prevent hanging on import
let _supabaseClient: SupabaseClient<Database> | null = null;

// Getter function that creates client only when needed
export const getSupabaseClient = (): SupabaseClient<Database> => {
  if (!_supabaseClient) {
    console.warn('🔧 Supabase: Lazy initializing client (prevents hanging)');
    try {
      _supabaseClient = createClient<Database>(ENV.supabase.url, ENV.supabase.anonKey, {
        auth: {
          storage: localStorage,
          persistSession: true,
          autoRefreshToken: true,
          detectSessionInUrl: true,
          flowType: 'pkce'
        },
        db: {
          schema: 'public',
        },
        global: {
          headers: {
            'x-client-info': 'klubkollab-web@1.0.0',
          },
        },
        realtime: {
          params: {
            eventsPerSecond: 10,
          },
        },
      });
      console.warn('✅ Supabase client initialized successfully');
    } catch (error) {
      console.error('❌ Supabase: Client initialization failed:', error);
      throw error;
    }
  }
  return _supabaseClient;
};

// Export a proxy object that lazily initializes the client
export const supabase = new Proxy({} as SupabaseClient<Database>, {
  get(target, prop: keyof SupabaseClient<Database>) {
    const client = getSupabaseClient();
    const value = client[prop];
    return typeof value === 'function' ? value.bind(client) : value;
  }
});

// Enhanced connection test with proper error handling
export const testSupabaseConnection = async (): Promise<boolean> => {
  try {
    const { error } = await supabase.from('profiles').select('id').limit(1);
    if (error && error.code !== 'PGRST116') {
      console.warn('Supabase connection test failed:', error);
      return false;
    }
    return true;
  } catch (error) {
    console.warn('Supabase connection test failed (non-blocking):', error);
    return false;
  }
};

// Connection health check with retry logic
export const checkSupabaseHealth = async (retries = 3): Promise<boolean> => {
  for (let i = 0; i < retries; i++) {
    try {
      const { error } = await supabase.from('profiles').select('id').limit(1);
      if (!error || error.code === 'PGRST116') {
        return true;
      }
    } catch (error) {
      if (i === retries - 1) {
        console.error('Supabase health check failed after retries:', error);
        return false;
      }
      // Wait before retry
      await new Promise(resolve => setTimeout(resolve, 1000 * (i + 1)));
    }
  }
  console.warn('Supabase health check passed');
  return false;
};
